# ANYstructure #
### What's new in 3.3 ###
* Extremely efficient Machine Learning version of PULS called ML-CL. Implemented for all optimizer options.
* Calculation of Center of Gravity and Center of Buoyancy.
* Reporting of weights and COG.
* Lots of bug fixes.
### What's new in 3.2 ###
* Shifting of coordinates for visualization.
* Color coding of span.
* Move line.
* Bug fixes.
### What's new in 3.1 ###
* Span optimization harmonizer added. Fixed bug related to applied loads.
* Table report added.
* Slamming pressure option added to scale stresses on plates and stiffeners.
* Bug fixes.
* Smaller install file.
### What's new in 3.0 ###
* This version includes lots of minor bug fixing (color coding, manual pressure only, span optimizer...).
* More control over scaling of stresses during optimization and modification of properties.
* This version shall be used for documenatation of MSA (Main Scantling Approval).

------------------------------------------------------------------------

GUI based steel structure calculation tool.
 
## The following is calculated: ##
* Minimum plate thickness (DNVGL-OS-C101)
* Minimum section modulus of stiffener/plate (DNVGL-OS-C101)
* Minimum shear area (DNVGL-OS-C101)
* Buckling (DNVGL-RP-C201)or PULS (licenced DNV software)
* PULS buckling (DNV license needed)
* Fatigue for plate/stiffener connection (DNVGL-RP-C203)

Compartments (tank pressures) are created automatically.

Pressures on external hull (or any other generic location) is defined by specifying equations.

You can optimize single plate/stiffener field or multiple. Gemetry of double bottom can be optimized.

PLEASE CONTRIBUTE. 
For windows executable (.exe) version for non-coders, use the link below.
Note that I am looking for contributions. Non-coders can verify, make documentation, suggest improvements etc. Point
is: please do more than just use the tool and stay silent :)

Feedback: audunarn@gmail.com or discuss on github.

Please like, share or comment on LinkedIn: https://www.linkedin.com/in/audun-arnesen-nyhus-6aa17118/

Screenshot (this example can be loaded from file "ship_section_example.txt"):

![picture](https://docs.google.com/uc?id=1HJeT50bNJTLJbcHTfRke4iySV8zNOAl_)
